import bpy
from bpy.types import Operator, PropertyGroup
from bpy.props import PointerProperty
from . import operators


def draw_viewport_shading_buttons(self, context):
    shading = context.space_data.shading

    # Check if the current shading mode is 'SOLID'
    if shading.type == 'SOLID':
        layout = self.layout

        # Add a label for the "Shading + Settings"
        layout.label(text="Shading + Settings")
        layout.separator()

        # Line 1: Save configuration buttons
        row = layout.row()
        row.operator("shading_plus.save_user_preset", text="Sync with User1", icon="USER")
        row.operator("shading_plus.save_user_preset", text="Sync with User2", icon="USER")

        # Line 2: Sync shadows button
        row = layout.row()
        row.operator("shading_plus.sync_shadow_settings", text="Sync Shadows", icon="OUTLINER_OB_LIGHT")
        row.operator("shading_plus.apply_viewport_colors", text="Apply Viewport Colors", icon="COLOR")


# REGISTER/UNREGISTER
# __________________________________________________________________

classes = (
    # Add any classes used in this module if needed
)

def register():
    for cls in classes:
        try:
            bpy.utils.unregister_class(cls)
        except RuntimeError:
            pass
        bpy.utils.register_class(cls)

    # Append the draw function to the VIEW3D_PT_shading panel
    bpy.types.VIEW3D_PT_shading.append(draw_viewport_shading_buttons)


def unregister():
    for cls in reversed(classes):
        bpy.utils.unregister_class(cls)

    # Remove the draw function from the VIEW3D_PT_shading panel
    bpy.types.VIEW3D_PT_shading.remove(draw_viewport_shading_buttons)


if __name__ == "__main__":
    register()
